#ifndef _CONTENT_WINDOW_H
#define _CONTENT_WINDOW_H

#include <QMainWindow>
#include <QWebView>
#include <QtGui>
#include <QtWebKit>
#include "googlereader.h"

class ContentWindow : public QMainWindow {
	Q_OBJECT

	public:
		ContentWindow(QWidget *parent = 0, Entry *e = 0);
		virtual ~ContentWindow();
		void closeEvent(QCloseEvent *event);
		void showEntry(Entry *e);

	public slots:
		void loadFinished(bool);
		void loadStarted();
		void seeOriginal();
		void showLink(const QUrl &);
		void toggleRead();
		void toggleShared();
		void toggleStarred();

	signals:
		void showNextEntry();
		void showPrevEntry();

	private:
		Entry *entry;
		QGraphicsWebView *webview;
		QAction *starred;
		QAction *shared;
		QAction *keepUnread;

		void grabZoomKeys(bool grab);
};

#endif

